;; Generated package description from xref.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "xref" "1.7.0.0.20260902.45" "Cross-referencing commands" '((emacs "26.1")) :commit "9df0d969ecb536a168c38255a38ea292c057c341" :url "https://elpa.gnu.org/packages/xref.html")
